@@ -7,7 +7,7 @@ package MarpaX::ESLIF::RegexCallout;
 
 our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
-our $VERSION = '6.0.9'; # TRIAL VERSION
+our $VERSION = '6.0.30'; # TRIAL VERSION
 
 
 use constant PCRE2_ERROR_NOMATCH => -1;
@@ -213,44 +213,44 @@ use constant PCRE2_ERROR_INTERNAL_DUPMATCH => -65;
 #
 
 
-sub getCalloutNumber { return shift->{callout_number} }
+sub getCalloutNumber { return $_[0]->{callout_number} }
 
 
 
-sub getCalloutString { return shift->{callout_string} }
+sub getCalloutString { return $_[0]->{callout_string} }
 
 
-sub getSubject { return shift->{subject} }
+sub getSubject { return $_[0]->{subject} }
 
 
-sub getPattern { return shift->{pattern} }
+sub getPattern { return $_[0]->{pattern} }
 
 
-sub getCaptureTop { return shift->{capture_top} }
+sub getCaptureTop { return $_[0]->{capture_top} }
 
 
-sub getCaptureLast { return shift->{capture_last} }
+sub getCaptureLast { return $_[0]->{capture_last} }
 
 
-sub getOffsetVector { return shift->{offset_vector} }
+sub getOffsetVector { return $_[0]->{offset_vector} }
 
 
-sub getMark { return shift->{mark} }
+sub getMark { return $_[0]->{mark} }
 
 
-sub getStartMatch { return shift->{start_match} }
+sub getStartMatch { return $_[0]->{start_match} }
 
 
-sub getCurrentPosition { return shift->{current_position} }
+sub getCurrentPosition { return $_[0]->{current_position} }
 
 
-sub getNextItem { return shift->{next_item} }
+sub getNextItem { return $_[0]->{next_item} }
 
 
-sub getGrammarLevel { return shift->{grammar_level} }
+sub getGrammarLevel { return $_[0]->{grammar_level} }
 
 
-sub getSymbolId { return shift->{symbol_id} }
+sub getSymbolId { return $_[0]->{symbol_id} }
 
 
 1;
@@ -267,7 +267,7 @@ MarpaX::ESLIF::RegexCallout - ESLIF Regex Callout
 
 =head1 VERSION
 
-version 6.0.9
+version 6.0.30
 
 =head1 SYNOPSIS
 
@@ -349,7 +349,7 @@ The callout function is interpreted as an integer, whose value conforms to PCRE2
 
 =item If the value is greater than zero, matching fails at the current point, but the testing of other matching possibilities goes ahead, just as if a lookahead assertion had failed.
 
-=item If the value is less than zero, the match is abandoned, and the matching function returns the negative value. 
+=item If the value is less than zero, the match is abandoned, and the matching function returns the negative value.
 
 =back
 
